<?php
/**
 * The Classic template to display the content
 *
 * Used for index/archive/search.
 *
 * @package WordPress
 * @subpackage LETTUCE
 * @since LETTUCE 1.0
 */

$lettuce_template_args = get_query_var( 'lettuce_template_args' );
if ( is_array( $lettuce_template_args ) ) {
	$lettuce_columns    = empty( $lettuce_template_args['columns'] ) ? 1 : max( 1, min( 3, $lettuce_template_args['columns'] ) );
	$lettuce_blog_style = array( $lettuce_template_args['type'], $lettuce_columns );
} else {
	$lettuce_blog_style = explode( '_', lettuce_get_theme_option( 'blog_style' ) );
	$lettuce_columns    = empty( $lettuce_blog_style[1] ) ? 1 : max( 1, min( 3, $lettuce_blog_style[1] ) );
}
$lettuce_expanded    = ! lettuce_sidebar_present() && lettuce_is_on( lettuce_get_theme_option( 'expand_content' ) );
$lettuce_post_format = get_post_format();
$lettuce_post_format = empty( $lettuce_post_format ) ? 'standard' : str_replace( 'post-format-', '', $lettuce_post_format );
$lettuce_animation   = lettuce_get_theme_option( 'blog_animation' );

?><article id="post-<?php the_ID(); ?>" 
									<?php
									post_class(
										'post_item'
										. ' post_layout_chess'
										. ' post_layout_chess_' . esc_attr( $lettuce_columns )
										. ' post_format_' . esc_attr( $lettuce_post_format )
										. ( ! empty( $lettuce_template_args['slider'] ) ? ' slider-slide swiper-slide' : '' )
									);
									echo ( ! lettuce_is_off( $lettuce_animation ) && empty( $lettuce_template_args['slider'] ) ? ' data-animation="' . esc_attr( lettuce_get_animation_classes( $lettuce_animation ) ) . '"' : '' );
									?>
	>

	<?php
	// Add anchor
	if ( 1 == $lettuce_columns && ! is_array( $lettuce_template_args ) && shortcode_exists( 'trx_sc_anchor' ) ) {
		echo do_shortcode( '[trx_sc_anchor id="post_' . the_title_attribute( array( 'echo' => false ) ) . '" title="' . esc_attr( get_the_title() ) . '" icon="' . esc_attr( lettuce_get_post_icon() ) . '"]' );
	}

	// Sticky label
	if ( is_sticky() && ! is_paged() ) {
		?>
		<span class="post_label label_sticky"></span>
		<?php
	}

	// Featured image
	$lettuce_hover = ! empty( $lettuce_template_args['hover'] ) && ! lettuce_is_inherit( $lettuce_template_args['hover'] )
						? $lettuce_template_args['hover']
						: lettuce_get_theme_option( 'image_hover' );
	lettuce_show_post_featured(
		array(
			'class'         => 1 == $lettuce_columns && ! is_array( $lettuce_template_args ) ? 'lettuce-full-height' : '',
			'singular'      => false,
			'hover'         => $lettuce_hover,
			'no_links'      => ! empty( $lettuce_template_args['no_links'] ),
			'show_no_image' => true,
			'thumb_bg'      => true,
			'thumb_size'    => lettuce_get_thumb_size(
				strpos( lettuce_get_theme_option( 'body_style' ), 'full' ) !== false
										? ( 1 < $lettuce_columns ? 'huge' : 'original' )
										: ( 2 < $lettuce_columns ? 'big' : 'huge' )
			),
		)
	);

	?>
	<div class="post_inner"><div class="post_inner_content"><div class="post_header entry-header">
		<?php
			do_action( 'lettuce_action_before_post_title' );

			// Post title
		if ( empty( $lettuce_template_args['no_links'] ) ) {
			the_title( sprintf( '<h3 class="post_title entry-title"><a href="%s" rel="bookmark">', esc_url( get_permalink() ) ), '</a></h3>' );
		} else {
			the_title( '<h3 class="post_title entry-title">', '</h3>' );
		}

			do_action( 'lettuce_action_before_post_meta' );

			// Post meta
			$lettuce_components = lettuce_array_get_keys_by_value( lettuce_get_theme_option( 'meta_parts' ) );
			$lettuce_counters   = lettuce_array_get_keys_by_value( lettuce_get_theme_option( 'counters' ) );
			$lettuce_post_meta  = empty( $lettuce_components ) || in_array( $lettuce_hover, array( 'border', 'pull', 'slide', 'fade' ) )
										? ''
										: lettuce_show_post_meta(
											apply_filters(
												'lettuce_filter_post_meta_args', array(
													'components' => $lettuce_components,
													'counters' => $lettuce_counters,
													'seo'  => false,
													'echo' => false,
												), $lettuce_blog_style[0], $lettuce_columns
											)
										);
			lettuce_show_layout( $lettuce_post_meta );
			?>
		</div><!-- .entry-header -->

		<div class="post_content entry-content">
		<?php
		if ( empty( $lettuce_template_args['hide_excerpt'] ) ) {
			?>
				<div class="post_content_inner">
				<?php
				if ( has_excerpt() ) {
					the_excerpt();
				} elseif ( strpos( get_the_content( '!--more' ), '!--more' ) !== false ) {
					the_content( '' );
				} elseif ( in_array( $lettuce_post_format, array( 'link', 'aside', 'status' ) ) ) {
					the_content();
				} elseif ( 'quote' == $lettuce_post_format ) {
					$quote = lettuce_get_tag( get_the_content(), '<blockquote>', '</blockquote>' );
					if ( ! empty( $quote ) ) {
						lettuce_show_layout( wpautop( $quote ) );
					} else {
						the_excerpt();
					}
				} elseif ( substr( get_the_content(), 0, 4 ) != '[vc_' ) {
					the_excerpt();
				}
				?>
				</div>
				<?php
		}
			// Post meta
		if ( in_array( $lettuce_post_format, array( 'link', 'aside', 'status', 'quote' ) ) ) {
			lettuce_show_layout( $lettuce_post_meta );
		}
			// More button
		if ( empty( $lettuce_template_args['no_links'] ) && ! in_array( $lettuce_post_format, array( 'link', 'aside', 'status', 'quote' ) ) ) {
			?>
				<p><a class="more-link" href="<?php echo esc_url( get_permalink() ); ?>"><?php esc_html_e( 'Read more', 'lettuce' ); ?></a></p>
				<?php
		}
		?>
		</div><!-- .entry-content -->

	</div></div><!-- .post_inner -->

</article>
