<?php
/**
 * The Classic template to display the content
 *
 * Used for index/archive/search.
 *
 * @package WordPress
 * @subpackage LETTUCE
 * @since LETTUCE 1.0
 */

$lettuce_template_args = get_query_var( 'lettuce_template_args' );
if ( is_array( $lettuce_template_args ) ) {
	$lettuce_columns    = empty( $lettuce_template_args['columns'] ) ? 2 : max( 2, $lettuce_template_args['columns'] );
	$lettuce_blog_style = array( $lettuce_template_args['type'], $lettuce_columns );
} else {
	$lettuce_blog_style = explode( '_', lettuce_get_theme_option( 'blog_style' ) );
	$lettuce_columns    = empty( $lettuce_blog_style[1] ) ? 2 : max( 2, $lettuce_blog_style[1] );
}
$lettuce_expanded   = ! lettuce_sidebar_present() && lettuce_is_on( lettuce_get_theme_option( 'expand_content' ) );
$lettuce_animation  = lettuce_get_theme_option( 'blog_animation' );
$lettuce_components = lettuce_array_get_keys_by_value( lettuce_get_theme_option( 'meta_parts' ) );
$lettuce_counters   = lettuce_array_get_keys_by_value( lettuce_get_theme_option( 'counters' ) );

$lettuce_post_format = get_post_format();
$lettuce_post_format = empty( $lettuce_post_format ) ? 'standard' : str_replace( 'post-format-', '', $lettuce_post_format );

?><div class="
<?php
if ( ! empty( $lettuce_template_args['slider'] ) ) {
	echo ' slider-slide swiper-slide';
} else {
	echo ( 'classic' == $lettuce_blog_style[0] ? 'column' : 'masonry_item masonry_item' ) . '-1_' . esc_attr( $lettuce_columns );
}
?>
"><article id="post-<?php the_ID(); ?>" 
	<?php
		post_class(
			'post_item post_format_' . esc_attr( $lettuce_post_format )
					. ' post_layout_classic post_layout_classic_' . esc_attr( $lettuce_columns )
					. ' post_layout_' . esc_attr( $lettuce_blog_style[0] )
					. ' post_layout_' . esc_attr( $lettuce_blog_style[0] ) . '_' . esc_attr( $lettuce_columns )
		);
		echo ( ! lettuce_is_off( $lettuce_animation ) && empty( $lettuce_template_args['slider'] ) ? ' data-animation="' . esc_attr( lettuce_get_animation_classes( $lettuce_animation ) ) . '"' : '' );
		?>
	>
	<?php

	// Sticky label
	if ( is_sticky() && ! is_paged() ) {
		?>
		<span class="post_label label_sticky"></span>
		<?php
	}

	// Featured image
	$lettuce_hover = ! empty( $lettuce_template_args['hover'] ) && ! lettuce_is_inherit( $lettuce_template_args['hover'] )
						? $lettuce_template_args['hover']
						: lettuce_get_theme_option( 'image_hover' );
	lettuce_show_post_featured(
		array(
			'thumb_size' => lettuce_get_thumb_size(
				'classic' == $lettuce_blog_style[0]
						? ( strpos( lettuce_get_theme_option( 'body_style' ), 'full' ) !== false
								? ( $lettuce_columns > 2 ? 'big' : 'huge' )
								: ( $lettuce_columns > 2
									? ( $lettuce_expanded ? 'med' : 'small' )
									: ( $lettuce_expanded ? 'big' : 'med' )
									)
							)
						: ( strpos( lettuce_get_theme_option( 'body_style' ), 'full' ) !== false
								? ( $lettuce_columns > 2 ? 'masonry-big' : 'full' )
								: ( $lettuce_columns <= 2 && $lettuce_expanded ? 'masonry-big' : 'masonry' )
							)
			),
			'hover'      => $lettuce_hover,
			'no_links'   => ! empty( $lettuce_template_args['no_links'] ),
			'singular'   => false,
		)
	);

	if ( ! in_array( $lettuce_post_format, array( 'link', 'aside', 'status', 'quote' ) ) ) {
		?>
		<div class="post_header entry-header">
			<?php
			do_action( 'lettuce_action_before_post_title' );

			// Post title
			if ( empty( $lettuce_template_args['no_links'] ) ) {
				the_title( sprintf( '<h4 class="post_title entry-title"><a href="%s" rel="bookmark">', esc_url( get_permalink() ) ), '</a></h4>' );
			} else {
				the_title( '<h4 class="post_title entry-title">', '</h4>' );
			}

			do_action( 'lettuce_action_before_post_meta' );

			// Post meta
			if ( ! empty( $lettuce_components ) && ! in_array( $lettuce_hover, array( 'border', 'pull', 'slide', 'fade' ) ) ) {
				lettuce_show_post_meta(
					apply_filters(
						'lettuce_filter_post_meta_args', array(
							'components' => $lettuce_components,
							'counters'   => $lettuce_counters,
							'seo'        => false,
						), $lettuce_blog_style[0], $lettuce_columns
					)
				);
			}

			do_action( 'lettuce_action_after_post_meta' );
			?>
		</div><!-- .entry-header -->
		<?php
	}
	?>

	<div class="post_content entry-content">
	<?php
	if ( empty( $lettuce_template_args['hide_excerpt'] ) ) {
		?>
			<div class="post_content_inner">
			<?php
			if ( has_excerpt() ) {
				the_excerpt();
			} elseif ( strpos( get_the_content( '!--more' ), '!--more' ) !== false ) {
				the_content( '' );
			} elseif ( in_array( $lettuce_post_format, array( 'link', 'aside', 'status' ) ) ) {
				the_content();
			} elseif ( 'quote' == $lettuce_post_format ) {
				$quote = lettuce_get_tag( get_the_content(), '<blockquote>', '</blockquote>' );
				if ( ! empty( $quote ) ) {
					lettuce_show_layout( wpautop( $quote ) );
				} else {
					the_excerpt();
				}
			} elseif ( substr( get_the_content(), 0, 4 ) != '[vc_' ) {
				the_excerpt();
			}
			?>
			</div>
			<?php
	}
		// Post meta
	if ( in_array( $lettuce_post_format, array( 'link', 'aside', 'status', 'quote' ) ) ) {
		if ( ! empty( $lettuce_components ) ) {
			lettuce_show_post_meta(
				apply_filters(
					'lettuce_filter_post_meta_args', array(
						'components' => $lettuce_components,
						'counters'   => $lettuce_counters,
					), $lettuce_blog_style[0], $lettuce_columns
				)
			);
		}
	}
		// More button
	if ( false && empty( $lettuce_template_args['no_links'] ) && ! in_array( $lettuce_post_format, array( 'link', 'aside', 'status', 'quote' ) ) ) {
		?>
			<p><a class="more-link" href="<?php echo esc_url( get_permalink() ); ?>"><?php esc_html_e( 'Read more', 'lettuce' ); ?></a></p>
			<?php
	}
	?>
	</div><!-- .entry-content -->

</article></div>
