<?php
/**
 * The default template to display the content
 *
 * Used for index/archive/search.
 *
 * @package WordPress
 * @subpackage LETTUCE
 * @since LETTUCE 1.0
 */

$lettuce_template_args = get_query_var( 'lettuce_template_args' );
if ( is_array( $lettuce_template_args ) ) {
	$lettuce_columns    = empty( $lettuce_template_args['columns'] ) ? 2 : max( 2, $lettuce_template_args['columns'] );
	$lettuce_blog_style = array( $lettuce_template_args['type'], $lettuce_columns );
	if ( ! empty( $lettuce_template_args['slider'] ) ) {
		?><div class="slider-slide swiper-slide">
		<?php
	} elseif ( $lettuce_columns > 1 ) {
		?>
		<div class="column-1_<?php echo esc_attr( $lettuce_columns ); ?>">
		<?php
	}
}
$lettuce_expanded    = ! lettuce_sidebar_present() && lettuce_is_on( lettuce_get_theme_option( 'expand_content' ) );
$lettuce_post_format = get_post_format();
$lettuce_post_format = empty( $lettuce_post_format ) ? 'standard' : str_replace( 'post-format-', '', $lettuce_post_format );
$lettuce_animation   = lettuce_get_theme_option( 'blog_animation' );
$lettuce_hover = ! empty( $lettuce_template_args['hover'] ) && ! lettuce_is_inherit( $lettuce_template_args['hover'] )
						? $lettuce_template_args['hover']
						: lettuce_get_theme_option( 'image_hover' );

?>
<article id="post-<?php the_ID(); ?>" 
	<?php post_class( 'post_item post_layout_excerpt post_format_' . esc_attr( $lettuce_post_format ) ); ?>
	<?php echo ( ! lettuce_is_off( $lettuce_animation ) && empty( $lettuce_template_args['slider'] ) ? ' data-animation="' . esc_attr( lettuce_get_animation_classes( $lettuce_animation ) ) . '"' : '' ); ?>
	>
	<?php

	// Sticky label
	if ( is_sticky() && ! is_paged() ) {
		?>
		    <div class="stycky_label"> <?php esc_html_e( 'Sticky Post', 'lettuce' )?></div>
		<?php
	}
    ?>
    <div class="header-meta_wraper"><?php
    // Post meta
    $lettuce_components = lettuce_array_get_keys_by_value( lettuce_get_theme_option( 'meta_parts' ) );
    $lettuce_counters   = lettuce_array_get_keys_by_value( lettuce_get_theme_option( 'counters' ) );

    if ( ! empty( $lettuce_components ) && ! in_array( $lettuce_hover, array( 'border', 'pull', 'slide', 'fade' ) ) ) {
        lettuce_show_post_meta(
            apply_filters(
                'lettuce_filter_post_meta_args', array(
                    'components' => $lettuce_components,
                    'counters'   => $lettuce_counters,
                    'seo'        => false,
                ), 'excerpt', 1
            )
        );
    }?>
    </div>
    <div class="full-content_wraper">
        <?php

	// Featured image
	lettuce_show_post_featured(
		array(
			'singular'   => false,
			'no_links'   => ! empty( $lettuce_template_args['no_links'] ),
			'hover'      => $lettuce_hover,
			'thumb_size' => lettuce_get_thumb_size( strpos( lettuce_get_theme_option( 'body_style' ), 'full' ) !== false ? 'full' : ( $lettuce_expanded ? 'huge' : (  in_array( $lettuce_post_format, array( 'audio' )) ? 'big' : 'blog' ) ) ),
		)
	);
?>
        <div class="post-content_wraper">
            <?php
        // Title and post meta
        if ( get_the_title() != '' ) {
            ?>

                <div class="post_header entry-header">
                    <?php
                    do_action( 'lettuce_action_before_post_title' );

                    // Post title
                    if ( empty( $lettuce_template_args['no_links'] ) ) {
                        the_title( sprintf( '<h2 class="post_title entry-title"><a href="%s" rel="bookmark">', esc_url( get_permalink() ) ), '</a></h2>' );
                    } else {
                        the_title( '<h2 class="post_title entry-title">', '</h2>' );
                    }

                    do_action( 'lettuce_action_before_post_meta' );

                    ?>
                </div><!-- .post_header -->
                <?php
            }

            // Post content
            if ( empty( $lettuce_template_args['hide_excerpt'] ) ) {

                ?>
                <div class="post_content entry-content">
                <?php
                if ( lettuce_get_theme_option( 'blog_content' ) == 'fullpost' ) {
                    // Post content area
                    ?>
                        <div class="post_content_inner">
                        <?php
                        the_content( '' );
                        ?>
                        </div>
                        <?php
                        // Inner pages
                        wp_link_pages(
                            array(
                                'before'      => '<div class="page_links"><span class="page_links_title">' . esc_html__( 'Pages:', 'lettuce' ) . '</span>',
                                'after'       => '</div>',
                                'link_before' => '<span>',
                                'link_after'  => '</span>',
                                'pagelink'    => '<span class="screen-reader-text">' . esc_html__( 'Page', 'lettuce' ) . ' </span>%',
                                'separator'   => '<span class="screen-reader-text">, </span>',
                            )
                        );
                } else {
                    // Post content area
                    ?>
                        <div class="post_content_inner">
                        <?php
                        if ( has_excerpt() ) {
                                the_excerpt();
                        } elseif ( strpos( get_the_content( '!--more' ), '!--more' ) !== false ) {
                                the_content( '' );
                        } elseif ( in_array( $lettuce_post_format, array( 'link', 'aside', 'status' ) ) ) {
                                                the_content();
                        } elseif ( 'quote' == $lettuce_post_format ) {
                            $quote = lettuce_get_tag( get_the_content(), '<blockquote>', '</blockquote>' );
                            if ( ! empty( $quote ) ) {
                                lettuce_show_layout( wpautop( $quote ) );
                            } else {
                                the_excerpt();
                            }
                        } elseif ( substr( get_the_content(), 0, 4 ) != '[vc_' ) {
                            the_excerpt();
                        }
                        ?>
                        </div>
                        <?php
                            // Post meta
                            $lettuce_components = lettuce_array_get_keys_by_value( lettuce_get_theme_option( 'meta_parts' ) );
                            $lettuce_counters   = lettuce_array_get_keys_by_value( lettuce_get_theme_option( 'counters' ) );

                            if ( ! empty( $lettuce_components ) && ! in_array( $lettuce_hover, array( 'border', 'pull', 'slide', 'fade' ) ) ) {
                                lettuce_show_post_meta(
                                    apply_filters(
                                        'lettuce_filter_post_meta_args', array(
                                            'components' => $lettuce_components,
                                            'counters'   => $lettuce_counters,
                                            'seo'        => false,
                                        ), 'excerpt', 1
                                    )
                                );
                            }
                }
                ?>
                </div><!-- .entry-content -->

            <?php
        }
        ?>
        </div>
	</div>
	</article>
<?php

if ( is_array( $lettuce_template_args ) ) {
	if ( ! empty( $lettuce_template_args['slider'] ) || $lettuce_columns > 1 ) {
		?>
		</div>
		<?php
	}
}
