<?php
/**
 * The Gallery template to display posts
 *
 * Used for index/archive/search.
 *
 * @package WordPress
 * @subpackage LETTUCE
 * @since LETTUCE 1.0
 */

$lettuce_template_args = get_query_var( 'lettuce_template_args' );
if ( is_array( $lettuce_template_args ) ) {
	$lettuce_columns    = empty( $lettuce_template_args['columns'] ) ? 2 : max( 2, $lettuce_template_args['columns'] );
	$lettuce_blog_style = array( $lettuce_template_args['type'], $lettuce_columns );
} else {
	$lettuce_blog_style = explode( '_', lettuce_get_theme_option( 'blog_style' ) );
	$lettuce_columns    = empty( $lettuce_blog_style[1] ) ? 2 : max( 2, $lettuce_blog_style[1] );
}
$lettuce_post_format = get_post_format();
$lettuce_post_format = empty( $lettuce_post_format ) ? 'standard' : str_replace( 'post-format-', '', $lettuce_post_format );
$lettuce_animation   = lettuce_get_theme_option( 'blog_animation' );
$lettuce_image       = wp_get_attachment_image_src( get_post_thumbnail_id( get_the_ID() ), 'full' );

?><article id="post-<?php the_ID(); ?>" 
									<?php
									post_class(
										'post_item'
										. ' post_layout_portfolio'
										. ' post_layout_gallery'
										. ' post_layout_gallery_' . esc_attr( $lettuce_columns )
										. ' post_format_' . esc_attr( $lettuce_post_format )
										. ( ! empty( $lettuce_template_args['slider'] ) ? ' slider-slide swiper-slide' : '' )
									);
									echo ( ! lettuce_is_off( $lettuce_animation ) && empty( $lettuce_template_args['slider'] ) ? ' data-animation="' . esc_attr( lettuce_get_animation_classes( $lettuce_animation ) ) . '"' : '' );
									?>
	data-size="
	<?php
	if ( ! empty( $lettuce_image[1] ) && ! empty( $lettuce_image[2] ) ) {
		echo intval( $lettuce_image[1] ) . 'x' . intval( $lettuce_image[2] );}
	?>
	"
	data-src="
	<?php
	if ( ! empty( $lettuce_image[0] ) ) {
		echo esc_url( $lettuce_image[0] );}
	?>
	"
>
<?php

	// Sticky label
if ( is_sticky() && ! is_paged() ) {
	?>
		<span class="post_label label_sticky"></span>
		<?php
}

	// Featured image
	$lettuce_image_hover = 'icon';
if ( in_array( $lettuce_image_hover, array( 'icons', 'zoom' ) ) ) {
	$lettuce_image_hover = 'dots';
}
	$lettuce_components = lettuce_array_get_keys_by_value( lettuce_get_theme_option( 'meta_parts' ) );
	$lettuce_counters   = lettuce_array_get_keys_by_value( lettuce_get_theme_option( 'counters' ) );
	lettuce_show_post_featured(
		array(
			'hover'         => $lettuce_image_hover,
			'singular'      => false,
			'no_links'      => ! empty( $lettuce_template_args['no_links'] ),
			'thumb_size'    => lettuce_get_thumb_size( strpos( lettuce_get_theme_option( 'body_style' ), 'full' ) !== false || $lettuce_columns < 3 ? 'masonry-big' : 'masonry' ),
			'thumb_only'    => true,
			'show_no_image' => true,
			'post_info'     => '<div class="post_details">'
							. '<h2 class="post_title">'
								. ( empty( $lettuce_template_args['no_links'] )
									? '<a href="' . esc_url( get_permalink() ) . '">' . esc_html( get_the_title() ) . '</a>'
									: esc_html( get_the_title() )
									)
							. '</h2>'
							. '<div class="post_description">'
								. ( ! empty( $lettuce_components )
									? lettuce_show_post_meta(
										apply_filters(
											'lettuce_filter_post_meta_args', array(
												'components' => $lettuce_components,
												'counters' => $lettuce_counters,
												'seo'      => false,
												'echo'     => false,
											), $lettuce_blog_style[0], $lettuce_columns
										)
									)
									: ''
									)
								. ( empty( $lettuce_template_args['hide_excerpt'] )
									? '<div class="post_description_content">' . get_the_excerpt() . '</div>'
									: ''
									)
								. ( empty( $lettuce_template_args['no_links'] )
									? '<a href="' . esc_url( get_permalink() ) . '" class="theme_button post_readmore"><span class="post_readmore_label">' . esc_html__( 'Learn more', 'lettuce' ) . '</span></a>'
									: ''
									)
							. '</div>'
						. '</div>',
		)
	);
	?>
	</article>
