<?php
/**
 * The default template to display the content of the single post, page or attachment
 *
 * Used for index/archive/search.
 *
 * @package WordPress
 * @subpackage LETTUCE
 * @since LETTUCE 1.0
 */

$lettuce_seo = lettuce_is_on( lettuce_get_theme_option( 'seo_snippets' ) );
?>

<article id="post-<?php the_ID(); ?>" 
									<?php
									post_class(
										'post_item_single post_type_' . esc_attr( get_post_type() )
												. ' post_format_' . esc_attr( str_replace( 'post-format-', '', get_post_format() ) )
									);
									if ( $lettuce_seo ) {
										?>
			itemscope="itemscope" 
			itemprop="articleBody" 
			itemtype="//schema.org/<?php echo esc_attr( lettuce_get_markup_schema() ); ?>"
			itemid="<?php the_permalink(); ?>"
			content="<?php the_title_attribute(); ?>"
										<?php
									}
									?>
>
<?php

	do_action( 'lettuce_action_before_post_data' );

	// Structured data snippets
if ( $lettuce_seo ) {
	get_template_part( apply_filters( 'lettuce_filter_get_template_part', 'templates/seo' ) );
}

	// Featured image
if ( lettuce_is_off( lettuce_get_theme_option( 'hide_featured_on_single' ) )
			&& ! lettuce_sc_layouts_showed( 'featured' )
			&& strpos( get_the_content(), '[trx_widget_banner]' ) === false ) {
	do_action( 'lettuce_action_before_post_featured' );
	lettuce_show_post_featured();
	do_action( 'lettuce_action_after_post_featured' );
} elseif ( has_post_thumbnail() ) {
	?>
		<meta itemprop="image" itemtype="//schema.org/ImageObject" content="<?php echo esc_url( wp_get_attachment_url( get_post_thumbnail_id() ) ); ?>">
		<?php
}
?>
    <div class="single-post_full_wraper">
    <?php
        // Title and post meta
    if ( ( ! lettuce_sc_layouts_showed( 'title' ) || ! lettuce_sc_layouts_showed( 'postmeta' ) ) && ! in_array( get_post_format(), array( 'link', 'aside', 'status', 'quote' ) ) ) {
        do_action( 'lettuce_action_before_post_title' );
        ?>
            <div class="post_header post_header_single entry-header">
            <?php
            // Post meta
            if ( ! lettuce_sc_layouts_showed( 'postmeta' ) && lettuce_is_on( lettuce_get_theme_option( 'show_post_meta' ) ) ) {
                lettuce_show_post_meta(
                    apply_filters(
                        'lettuce_filter_post_meta_args', array(
                        'components' => lettuce_array_get_keys_by_value( lettuce_get_theme_option( 'meta_parts_post' ) ),
                        'counters'   => lettuce_array_get_keys_by_value( lettuce_get_theme_option( 'counters' ) ),
                        'seo'        => lettuce_is_on( lettuce_get_theme_option( 'seo_snippets' ) ),
                    ), 'single', 1
                    )
                );
            }
            ?>
            </div><!-- .post_header -->
            <?php
            do_action( 'lettuce_action_after_post_title' );
    }

        do_action( 'lettuce_action_before_post_content' );

        // Post content
    ?>
        <div class="post_content post_content_single entry-content" itemprop="mainEntityOfPage">
            <?php
            the_content();

            do_action( 'lettuce_action_before_post_pagination' );

            wp_link_pages(
                array(
                    'before'      => '<div class="page_links"><span class="page_links_title">' . esc_html__( 'Pages:', 'lettuce' ) . '</span>',
                    'after'       => '</div>',
                    'link_before' => '<span>',
                    'link_after'  => '</span>',
                    'pagelink'    => '<span class="screen-reader-text">' . esc_html__( 'Page', 'lettuce' ) . ' </span>%',
                    'separator'   => '<span class="screen-reader-text">, </span>',
                )
            );

            // Taxonomies and share
            if ( is_single() && ! is_attachment() ) {

                do_action( 'lettuce_action_before_post_meta' );
                get_the_tag_list();
                // Post rating
                do_action(
                    'trx_addons_action_post_rating', array(
                        'class'                => 'single_post_rating',
                        'rating_text_template' => esc_html__( 'Post rating: {{X}} from {{Y}} (according {{V}})', 'lettuce' ),
                    )
                );

                ?>
                <div class="post_meta post_meta_single">
                <?php

                // Post meta
                if ( ! lettuce_sc_layouts_showed( 'postmeta' ) && lettuce_is_on( lettuce_get_theme_option( 'show_post_meta' ) ) ) {
                    lettuce_show_post_meta(
                        apply_filters(
                            'lettuce_filter_post_meta_args', array(
                            'components' => lettuce_array_get_keys_by_value( lettuce_get_theme_option( 'meta_parts_post' ) ),
                            'counters'   => lettuce_array_get_keys_by_value( lettuce_get_theme_option( 'counters' ) ),
                            'seo'        => lettuce_is_on( lettuce_get_theme_option( 'seo_snippets' ) ),
                        ), 'single', 1
                        )
                    );
                }

                    // Share
                if ( lettuce_is_on( lettuce_get_theme_option( 'show_share_links' ) ) ) {
                    lettuce_show_share_links(
                        array(
                            'type'    => 'block',
                            'caption' => 'share:',
                            'before'  => '<span class="post_meta_item post_share">',
                            'after'   => '</span>',
                        )
                    );
                }
                ?>
                </div>
                <?php

                do_action( 'lettuce_action_after_post_meta' );
            }
            ?>
        </div><!-- .entry-content -->
    </div>
	<?php
	do_action( 'lettuce_action_after_post_content' );

	// Author bio
	if ( lettuce_get_theme_option( 'show_author_info' ) == 1 && is_single() && ! is_attachment() && get_the_author_meta( 'description' ) ) {
		do_action( 'lettuce_action_before_post_author' );
		get_template_part( apply_filters( 'lettuce_filter_get_template_part', 'templates/author-bio' ) );
		do_action( 'lettuce_action_after_post_author' );
	}

	do_action( 'lettuce_action_after_post_data' );
	?>
</article>
