<?php
/**
 * The template for homepage posts with "Portfolio" style
 *
 * @package WordPress
 * @subpackage LETTUCE
 * @since LETTUCE 1.0
 */

lettuce_storage_set( 'blog_archive', true );

get_header();

if ( have_posts() ) {

	lettuce_blog_archive_start();

	$lettuce_stickies   = is_home() ? get_option( 'sticky_posts' ) : false;
	$lettuce_sticky_out = lettuce_get_theme_option( 'sticky_style' ) == 'columns'
							&& is_array( $lettuce_stickies ) && count( $lettuce_stickies ) > 0 && get_query_var( 'paged' ) < 1;

	// Show filters
	$lettuce_cat          = lettuce_get_theme_option( 'parent_cat' );
	$lettuce_post_type    = lettuce_get_theme_option( 'post_type' );
	$lettuce_taxonomy     = lettuce_get_post_type_taxonomy( $lettuce_post_type );
	$lettuce_show_filters = lettuce_get_theme_option( 'show_filters' );
	$lettuce_tabs         = array();
	if ( ! lettuce_is_off( $lettuce_show_filters ) ) {
		$lettuce_args           = array(
			'type'         => $lettuce_post_type,
			'child_of'     => $lettuce_cat,
			'orderby'      => 'name',
			'order'        => 'ASC',
			'hide_empty'   => 1,
			'hierarchical' => 0,
			'taxonomy'     => $lettuce_taxonomy,
			'pad_counts'   => false,
		);
		$lettuce_portfolio_list = get_terms( $lettuce_args );
		if ( is_array( $lettuce_portfolio_list ) && count( $lettuce_portfolio_list ) > 0 ) {
			$lettuce_tabs[ $lettuce_cat ] = esc_html__( 'All', 'lettuce' );
			foreach ( $lettuce_portfolio_list as $lettuce_term ) {
				if ( isset( $lettuce_term->term_id ) ) {
					$lettuce_tabs[ $lettuce_term->term_id ] = $lettuce_term->name;
				}
			}
		}
	}
	if ( count( $lettuce_tabs ) > 0 ) {
		$lettuce_portfolio_filters_ajax   = true;
		$lettuce_portfolio_filters_active = $lettuce_cat;
		$lettuce_portfolio_filters_id     = 'portfolio_filters';
		?>
		<div class="portfolio_filters lettuce_tabs lettuce_tabs_ajax">
			<ul class="portfolio_titles lettuce_tabs_titles">
				<?php
				foreach ( $lettuce_tabs as $lettuce_id => $lettuce_title ) {
					?>
					<li><a href="<?php echo esc_url( lettuce_get_hash_link( sprintf( '#%s_%s_content', $lettuce_portfolio_filters_id, $lettuce_id ) ) ); ?>" data-tab="<?php echo esc_attr( $lettuce_id ); ?>"><?php echo esc_html( $lettuce_title ); ?></a></li>
					<?php
				}
				?>
			</ul>
			<?php
			$lettuce_ppp = lettuce_get_theme_option( 'posts_per_page' );
			if ( lettuce_is_inherit( $lettuce_ppp ) ) {
				$lettuce_ppp = '';
			}
			foreach ( $lettuce_tabs as $lettuce_id => $lettuce_title ) {
				$lettuce_portfolio_need_content = $lettuce_id == $lettuce_portfolio_filters_active || ! $lettuce_portfolio_filters_ajax;
				?>
				<div id="<?php echo esc_attr( sprintf( '%s_%s_content', $lettuce_portfolio_filters_id, $lettuce_id ) ); ?>"
					class="portfolio_content lettuce_tabs_content"
					data-blog-template="<?php echo esc_attr( lettuce_storage_get( 'blog_template' ) ); ?>"
					data-blog-style="<?php echo esc_attr( lettuce_get_theme_option( 'blog_style' ) ); ?>"
					data-posts-per-page="<?php echo esc_attr( $lettuce_ppp ); ?>"
					data-post-type="<?php echo esc_attr( $lettuce_post_type ); ?>"
					data-taxonomy="<?php echo esc_attr( $lettuce_taxonomy ); ?>"
					data-cat="<?php echo esc_attr( $lettuce_id ); ?>"
					data-parent-cat="<?php echo esc_attr( $lettuce_cat ); ?>"
					data-need-content="<?php echo ( false === $lettuce_portfolio_need_content ? 'true' : 'false' ); ?>"
				>
					<?php
					if ( $lettuce_portfolio_need_content ) {
						lettuce_show_portfolio_posts(
							array(
								'cat'        => $lettuce_id,
								'parent_cat' => $lettuce_cat,
								'taxonomy'   => $lettuce_taxonomy,
								'post_type'  => $lettuce_post_type,
								'page'       => 1,
								'sticky'     => $lettuce_sticky_out,
							)
						);
					}
					?>
				</div>
				<?php
			}
			?>
		</div>
		<?php
	} else {
		lettuce_show_portfolio_posts(
			array(
				'cat'        => $lettuce_cat,
				'parent_cat' => $lettuce_cat,
				'taxonomy'   => $lettuce_taxonomy,
				'post_type'  => $lettuce_post_type,
				'page'       => 1,
				'sticky'     => $lettuce_sticky_out,
			)
		);
	}

	lettuce_blog_archive_end();

} else {

	if ( is_search() ) {
		get_template_part( apply_filters( 'lettuce_filter_get_template_part', 'content', 'none-search' ), 'none-search' );
	} else {
		get_template_part( apply_filters( 'lettuce_filter_get_template_part', 'content', 'none-archive' ), 'none-archive' );
	}
}

get_footer();
